Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(537)

Unified Diff: components/nacl/common/nacl_host_messages.h

Issue 649603004: Non-SFI NaCl: Batch-open resource files (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: code review Created 5 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/nacl/common/nacl_host_messages.h
diff --git a/components/nacl/common/nacl_host_messages.h b/components/nacl/common/nacl_host_messages.h
index b57ff1d56aa13239d201911d4e2b72bc00a2b70b..251c4663e1d46a51a4c3dea53ae206f0ccdcb02a 100644
--- a/components/nacl/common/nacl_host_messages.h
+++ b/components/nacl/common/nacl_host_messages.h
@@ -25,6 +25,7 @@ IPC_STRUCT_TRAITS_BEGIN(nacl::NaClLaunchParams)
IPC_STRUCT_TRAITS_MEMBER(nexe_file)
IPC_STRUCT_TRAITS_MEMBER(nexe_token_lo)
IPC_STRUCT_TRAITS_MEMBER(nexe_token_hi)
+ IPC_STRUCT_TRAITS_MEMBER(resource_files_info)
IPC_STRUCT_TRAITS_MEMBER(render_view_id)
IPC_STRUCT_TRAITS_MEMBER(permission_bits)
IPC_STRUCT_TRAITS_MEMBER(uses_nonsfi_mode)
@@ -52,6 +53,13 @@ IPC_STRUCT_TRAITS_BEGIN(nacl::PnaclCacheInfo)
IPC_STRUCT_TRAITS_MEMBER(extra_flags)
IPC_STRUCT_TRAITS_END()
+IPC_STRUCT_TRAITS_BEGIN(nacl::NaClResourceFileInfo)
+ IPC_STRUCT_TRAITS_MEMBER(file)
+ IPC_STRUCT_TRAITS_MEMBER(file_token_lo)
+ IPC_STRUCT_TRAITS_MEMBER(file_token_hi)
+ IPC_STRUCT_TRAITS_MEMBER(key)
+IPC_STRUCT_TRAITS_END()
+
// A renderer sends this to the browser process when it wants to start
// a new instance of the Native Client process. The browser will launch
// the process and return an IPC channel handle. This handle will only
@@ -68,7 +76,7 @@ IPC_SYNC_MESSAGE_CONTROL2_3(NaClHostMsg_GetReadonlyPnaclFD,
bool /* is_executable */,
IPC::PlatformFileForTransit /* output file */,
Yusuke Sato 2015/02/11 05:54:21 reverted to the original code
uint64_t /* file_token_lo */,
- uint64_t /* file_token_hi */)
+ uint64_t /* file_token_hi */);
Mark Seaborn 2015/02/12 03:57:33 Nit: remove stray semicolon
Yusuke Sato 2015/02/13 23:01:16 Done.
// A renderer sends this to the browser process when it wants to
// create a temporary file.
@@ -103,13 +111,12 @@ IPC_MESSAGE_CONTROL1(NaClHostMsg_MissingArchError,
// A renderer sends this to the browser process when it wants to
// open a NaCl executable file from an installed application directory.
Mark Seaborn 2015/02/12 03:57:33 I think this comment needs updating.
Yusuke Sato 2015/02/13 23:01:16 Done (reverted to the original IPC definition)
-IPC_SYNC_MESSAGE_CONTROL3_3(NaClHostMsg_OpenNaClExecutable,
- int /* render_view_id */,
- GURL /* URL of NaCl executable file */,
- bool /* enable_validation_caching */,
- IPC::PlatformFileForTransit /* output file */,
- uint64 /* file_token_lo */,
- uint64 /* file_token_hi */)
+IPC_SYNC_MESSAGE_CONTROL3_1(
+ NaClHostMsg_OpenNaClResources,
+ int /* render_view_id */,
+ std::vector<GURL> /* URLs of NaCl resource files */,
+ bool /* enable_validation_caching */,
+ std::vector<nacl::NaClResourceFileInfo> /* open_result */)
// A renderer sends this to the browser process to determine how many
// processors are online.

Powered by Google App Engine
This is Rietveld 408576698